#
# spec file for package xfce4-panel
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with git
%define libname libxfce4panel-2_0-4

Name:           xfce4-panel
Version:        4.20.3
Release:        1.1
Summary:        Panel for the Xfce Desktop Environment
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/xfce/xfce4-panel/start
Source0:        https://archive.xfce.org/src/xfce/%{name}/4.20/%{name}-%{version}.tar.bz2
Source1:        %{name}-rpmlintrc
Source2:        %{name}-restore-defaults
Source3:        %{name}-restore-defaults.desktop
BuildRequires:  desktop-file-utils
BuildRequires:  ed
BuildRequires:  fdupes
BuildRequires:  gettext >= 0.19.8
BuildRequires:  gtk-doc
BuildRequires:  perl
BuildRequires:  update-desktop-files

BuildRequires:  pkgconfig(atk)
BuildRequires:  pkgconfig(cairo) >= 1.16.0
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(dbusmenu-gtk3-0.4) >= 16.04.0
BuildRequires:  pkgconfig(exo-2) >= 0.11.2
BuildRequires:  pkgconfig(garcon-1) >= 4.17.0
BuildRequires:  pkgconfig(garcon-gtk3-1) >= 4.17.0
BuildRequires:  pkgconfig(gdk-wayland-3.0) >= 3.24.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.72.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.0
BuildRequires:  pkgconfig(gtk-layer-shell-0) >= 0.7.0
BuildRequires:  pkgconfig(libwnck-3.0) >= 3.0
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.17.1
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.17.2
BuildRequires:  pkgconfig(libxfce4windowing-0) >= 4.20.1
BuildRequires:  pkgconfig(libxfconf-0) >= 4.13.2
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(vapigen)
BuildRequires:  pkgconfig(wayland-client) >= 1.20
BuildRequires:  pkgconfig(x11) >= 1.6.7
BuildRequires:  pkgconfig(xext) >= 1.0.0
# Needs xdt-csource provided by xfce4-dev-tools
BuildRequires:  xfce4-dev-tools
# typelib(AppIndicator3) is needed for statusnotifier plugin to be fully usable with appindicators
Requires:       typelib(AppIndicator3)
Provides:       xfce4-panel-doc = %{version}
Obsoletes:      xfce4-panel-doc <= 4.12.0
Provides:       xfce4-panel-plugins = %{version}
Obsoletes:      xfce4-panel-plugins < %{version}
Provides:       xfce4-statusnotifier-plugin = %{version}
Obsoletes:      xfce4-statusnotifier-plugin <= 0.2.2
Provides:       xfce4-statusnotifier-plugin-lang = %{version}
Obsoletes:      xfce4-statusnotifier-plugin-lang <= 0.2.2
Recommends:     %{name}-lang = %{version}
Requires:       %{name}-branding = %{version}
Recommends:     %{name}-restore-defaults

%description
xfce4-panel is the panel for the Xfce desktop environment.

%package        devel
Summary:        Development Files for xfce4-panel
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
The xfce4-panel-devel package contains development files needed to to develop
panel plugins.

%package -n typelib-1_0-Libxfce4panel-2_0
Summary:        Xfce Panel Shared Library
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries

%description -n typelib-1_0-Libxfce4panel-2_0
GObject introspection bindings for Xfce Panel

%package -n %{libname}
Summary:        Xfce Panel Shared Library
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries

%description -n %{libname}
This package contains GTK 3 variant of the xfce4-panel shared library.

%package branding-upstream
Summary:        Upstream Branding for xfce4-panel
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
Supplements:    packageand(%{name}:branding-upstream)
Conflicts:      otherproviders(%{name}-branding)
Provides:       %{name}-branding = %{version}
#BRAND: Provide default panel configuration in /etc/xdg/xfce4/panel/default.xml
BuildArch:      noarch

%description branding-upstream
This package provides the upstream look and feel for xfce4-panel.

%package restore-defaults
Summary:        Script to restore Xfce Panel Defaults
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/GUI/XFCE
Requires:       zenity

%description restore-defaults
This package provides a script %{_bindir}/%{name}-restore-defaults which calls allows to restore the Xfce Panel factory defaults.
A desktop file and application launcher is provided.

%lang_package

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
    --enable-maintainer-mode \
    --with-helper-path-prefix=%{_libexecdir} \
    --enable-vala=yes \
    --disable-static
%else
%configure \
    --with-helper-path-prefix=%{_libexecdir} \
    --enable-vala=yes \
    --disable-static
%endif
%make_build

%install
%make_install

install -m0755 %{SOURCE2} %{buildroot}/%{_bindir}/%{name}-restore-defaults

desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE3}

rm -f %{buildroot}%{_libdir}/*.la \
    %{buildroot}%{_libdir}/xfce4/panel/plugins/*.la \
    %{buildroot}%{_datadir}/xfce4/xfce4-panel/README.gtkrc-2.0

mkdir -p %{buildroot}%{_datadir}/xfce4/panel-plugins
mkdir -p %{buildroot}%{_libdir}/xfce4/panel-plugins
mkdir -p %{buildroot}%{_libexecdir}/xfce4/panel-plugins

%suse_update_desktop_file panel-desktop-handler
%suse_update_desktop_file panel-preferences

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name}

%fdupes %{buildroot}%{_includedir}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%if %{with git}
%doc AUTHORS NEWS README.md
%else
%doc AUTHORS ChangeLog NEWS README.md
%endif
%license COPYING COPYING.LIB
%{_bindir}/xfce4-panel
%{_bindir}/xfce4-popup-applicationsmenu
%{_bindir}/xfce4-popup-directorymenu
%{_bindir}/xfce4-popup-windowmenu
%dir %{_libexecdir}/xfce4/panel
%{_libexecdir}/xfce4/panel/migrate
%{_libexecdir}/xfce4/panel/wrapper-2.0
%dir %{_datadir}/xfce4/panel-plugins
%{_datadir}/xfce4/panel/
%{_datadir}/applications/panel-*.desktop
%{_datadir}/icons/hicolor/*/apps/org.xfce.panel*
%dir %{_libexecdir}/xfce4/panel-plugins
%{_libdir}/xfce4/panel/
%dir %{_sysconfdir}/xdg/xfce4/panel

%files lang -f %{name}.lang

%files -n typelib-1_0-Libxfce4panel-2_0
%{_libdir}/girepository-1.0/Libxfce4panel-2.0.typelib

%files -n %{libname}
%license COPYING
%{_libdir}/libxfce4panel-2.0.so.*

%files devel
%{_includedir}/xfce4/libxfce4panel-*
%{_libdir}/libxfce4panel-*.so
%{_libdir}/pkgconfig/libxfce4panel-*.pc
%{_datadir}/gtk-doc/html/libxfce4panel-*
%{_datadir}/vala/vapi/libxfce4panel-2.0.*
%{_datadir}/gir-1.0/Libxfce4panel-2.0.gir

%files branding-upstream
%config %{_sysconfdir}/xdg/xfce4/panel/default.xml

%files restore-defaults
%{_bindir}/xfce4-panel-restore-defaults
%{_datadir}/applications/%{name}-restore-defaults.desktop

%changelog
* Tue Feb  4 2025 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.20.3:
  * libxfce4panel: Fix ABI break
  * meson-build: Update debug/optimization flag management
- Version 4.20.2:
  * autotools-build: Get rid of maintainer mode where gdbus-codegen is used
- Version 4.20.1:
  * build: Bump libxfce4windowing required version to 4.20.1
  * Update copyright year
  * meson-build: Don't add 'lib' prefix in static lib name
  * meson-build: Simplify feature opt dep management
  * meson-build: Ensure xfce-revision.h was generated when using it
  * build: Use VERSION_FULL intead of VERSION or PACKAGE_VERSION
  * autotools-build: Fix EXTRA_DIST redefinition
  * meson-build: Remove unneeded conditional
  * actions: Restore dialog accept on Enter behavior
  * Add meson build
  * Turn some messages into warnings
  * build: Migrate to xdt-gen-visibility and xdt-check-abi
  * wayland: windowmenu: Hide irrelevant workspace options
  * wayland: pager: Hide workspace settings
  * docs: Add missing parameter to XfcePanelPlugin::hidden-event
  * wayland: libxfce4panel: Set kbd interact to on-demand for popup windows
  * tasklist: Add missing workspace property initialization on Wayland
  * panel: Deal with duplicated monitor models
  * tasklist: Disable workspace related properties on Wayland
  * prefs-dialog: Don't trust xfconf_channel_get_string_list() return value
  * libxfce4panel: Fix XfcePanelPlugin size
  * Add an hidden-event signal for plugins
  * Translation Updates
- Removed obsolete 0001-relax-x11-version.patch
- Added BuildRequires:  xfce4-dev-tools as build needs xdt-csource provided by xfce4-dev-tools
* Sun Dec 15 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.20.0
  * Translation Updates
- Refresh 0001-relax-x11-version.patch
* Sun Dec  1 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.7 [development branch]
  * I18n: Update po/LINGUAS list
  * migrate: Update default config
  * tasklist: Ensure group buttons have non empty label
  * Translation Updates
- Refresh 0001-relax-x11-version.patch
* Sat Nov  2 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.6 [development branch]
  * systray: Handle general container orientation on Wayland too
  * systray: Fix GSList element leak
  * migrate/default.xml.in: Remove unused plugin id
  * Added "show inactive" prop to lcd clock (repurposed from binary
    clock)
  * Reworked sizing mechanism in clock plugin and its widgets
  * Reduce minimum button size to improve layout at very small panel
    sizes.
  * Use width_for_height when plugin requests it
  * LCD and digital clock layout fixes
  * systray: Fix leak in sn_plugin_init
  * Added a missing property bind for 24hr analogue clock
  * Added XFCE_PANEL_PLUGIN_ICON_PADDING (API change)
  * tasklist: Keep icon sizes as specified by the user
  * Revert "wayland: tasklist: Fix icon size in multirow mode"
  * systray: Add missing translation
  * clock: Added 24h clock mode to the analog clock
  * Translation Updates
- Add 0001-relax-x11-version.patch to allow build for Leap with its
  ancient but sufficient X11 packages.
* Mon Oct  7 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.5 [development branch]
  * Use new xfw_window_activate() signature in libwindowing 4.19.6
  * build: Adjust Wayland requirements for Xfce 4.20
  * build: Bump requirements for Xfce 4.20
  * wayland: tasklist: Fix monitor detection when panel is remapped
  * x11: tasklist: Properly check for libxext
  * wayland: autohide: Do not block when panel has input focus
  * Revert "panel: Fix panel flickering during autohide on Wayland"
  * wayland: autohide: Show/hide panel instead of moving it offscreen
  * autohide: Show/hide autohide window instead of moving it offscreen
  * wayland: Avoid allocation loop when the panel is anchored to an edge
  * Revert "wayland: Avoid allocation loop when the panel is anchored to
    an edge"
  * wayland: Avoid allocation loop when the panel is anchored to an edge
  * Fix gtk-layer-shell includes
  * Switch to XfwMonitor
  * wayland: wrapper: Prevent plugin allocation blocking
  * tasklist: Connect to XfwWindow::notify::monitors
  * panel: Fix panel flickering during autohide on Wayland
  * Always set gtk_layer_shell monitor on change
  * Add debug key for PANEL_DEBUG_ACTIONS
  * tasklist: Fix Wayland window drag and drop
  * panel: Do not remove plugin when disregarding restart dialog
  * panel: Replace remaining gtk_message_dialog_new with
    xfce_message_dialog_new
  * common: Introduce panel_utils_gtk_dialog_find_label_by_text
  * tasklist: Use xfce_dialog_show_error when starting new instance fails
  * actions: Use xfce_message_dialog_new in confirmation dialogs
  * panel, libxfce4panel: Use xfce_dialog_confirm in plugin removal
    confirmation
  * gcc-analyzer: Add false positive file
  * scan-build: Add false positive file
  * scan-build: tasklist: Fix core.NullDereference
  * Revert "Add new CI builds to build without X11 and Wayland"
  * Apply .clang-format file
  * Remove unnecessary dirname in local includes
  * clang-format: Use IncludeBlocks::Regroup
  * build: Add missing CFLAGS and LIBS from gio-unix-2.0
  * build: Add missing math.h includes
  * build: Silence -Wstring-plus-int from clang
  * fix build on OpenBSD after 0c56766b
  * Translation Updates
- Update to version 4.18.4 [development branch]
  * clang-format: Break after assignment operator
  * Add missing glade file to POTFILES.in
  * showdesktop: Add the ability to show the desktop on mouse hover
  * prefs-dialog: Improve launcher display in item list
  * systray: Avoid GTK warning about pixbuf not loadable
  * panel: Leave a harmless xfconf warning
  * clang-format: Insert a newline at end of file if missing
  * libxfce4panel: Add line break in generate code for clang-format
  * prefs-dialog: Bind Del key to remove button
  * prefs-dialog: Scroll to selection when item view is reloaded
  * prefs-dialog: Allow several items to be removed at once
  * prefs-dialog: Update widgets on GdkDisplay::monitor-(added|removed)
  * systray: Always scale icons
  * systray: Reduce icon size in prefs dialog
  * systray: Improve app data search in prefs dialog
  * systray: Avoid duplicate code around legacy items
  * systray: Use panel_properties_bind()
  * panel: Save settings in finalize()
  * tasklist: Fix min button length before overflow menu
  * tasklist: Fix default button length
  * build: Add missing math.h include
  * Apply .clang-format file
  * Clean up and sort includes
  * Various preliminary cleanup
  * clang-format: Add file
  * windowmenu: Remove a duplicate check
  * Remove dead code
  * tasklist: Sanitize XfwApplication management
  * Minor spelling/grammar corrections in comments
  * POTFILES.in: Remove untranslated file
  * panel: Define constants common to window and itembar
  * windowmenu: Clamp style properties
  * tasklist: Allow -1 for menu-max-width-chars
  * panel: Restrict admissible values of style properties
  * tasklist: Fix use of min-button-length
  * tasklist: Fix use of max-button-length
  * tasklist: Clamp style properties
  * actions: Add some fallback methods if there is no session proxy
  * actions: Ask xfce4-session to switch user if possible
  * actions: Fix wrong parameter allow_save for Shutdown and Restart
  * actions: Let xfce4-session manage its settings internally
  * actions: Rework D-Bus proxy management
  * Reintroduce panel_properties_get_channel()
  * Ask user what to do in case of plugin loading failure
  * Check for xfconf init in main.c and exit on failure
  * Fix wrong string comparison
  * prefs-dialog: Do not close when opening panel-profiles
  * Revert "prefs-dialog: Launch xfce4-panel-profiles with '--from-panel'"
  * Try to derive plugin dirs from XDG_DATA_DIRS
  * Remove NDEBUG compiler switchs
  * launcher: Delete unprotected X11 code at runtime
  * actions: Populate plugin earlier
  * systray: Avoid floating point exception
  * panel: Use gdk_cursor_new_from_name() to be more cross-platform
  * wayland: pager: Add missing runtime check
  * panel: Implement per window CSS customization
  * panel: Add border width option
  * itembar: Let GtkContainer handle border width
  * panel: Fix -Wmaybe-uninitialized warning
  * panel: Return silently when n_monitors == 0
  * tasklist: Do not call xfw_window_x11_get_xid() on Wayland
  * Translation Updates
* Tue Apr  2 2024 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.19.3 (development branch)
* Thu Feb 29 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.6
  * Update copyright year
  * Do not use g_log_set_always_fatal()
  * launcher: Ensure default icon in empty launchers
  * build: Search for bind_textdomain_codeset in libintl too
  * Fix memory management of GTypeModules
  * pager: Avoid recursion in WnckScren signal handler
  * pager: Do not query workspace count if screen is not initialized
  * libxfce4panel: Fix custom menu items management
  * clock: Create monitor proxy asynchronously
  * Add missing G_BEGIN_DECLS
  * Translation Updates
* Fri Sep 29 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.5
  * pager: Do not adapt upper value of spin button in viewport mode
  * pager: Update workspace layout also on window manager change
  * pager: Fix aspect ratio for viewport (V2)
  * actions: Fix memory leak
  * pager: Delay GdkScreen signal handlers
  * panel: Do not scale background image when UI scale > 1
  * popup-command: Do not block autohide when popped up at pointer
  * Fix memory leaks when using gtk_css_provider_new()
  * panel: Clear item list before repopulating item dialog
  * panel: Remove autosave timer for plugins
  * wrapper: Really ensure we don't call gtk_main_quit() twice
  * panel: Block autohide when the panel has input focus
  * clock: Fix sync timeout for seconds display
  * clock: Implement ConsoleKit sleep monitor
  * Add/Sharpen icons at 48-128px
  * Adjust 32px icon margins, new separator icon
  * Sharpen icons at 16px and 32px
  * Increase margins for 24px icons
  * Make 24px icons sharper
  * icons: Fix wrong exported sizes
  * Translation Updates
* Sat Apr 22 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.4
  * icons: Scale at size 16x16 to 128x128 (Fixes #385)
  * icons: Fix centering of org.xfce.panel
  * icons: Rename org.xfce.panel.statustray to org.xfce.panel.systray
  * Fix memory leaks around gtk_get_current_event()
  * tasklist: Fix use-after-free on tasklist child
  * systray: Update icon also on status change
  * Translation Updates
* Tue Mar 28 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.3
  * launcher: Show action menu also when there are several items
  * Fix memory management of vala generated plugins
  * panel: Rephrase "Don't reserve space on borders" (V2)
  * panel: Make property migration generic
  * launcher: Avoid "no trigger event" warning when showing the menu
  * launcher: Guard access to the plugin menu GdkWindow
  * libxfce4panel: Unregister menu also on GtkWidget::hide
  * panel: Do not reset output name if a monitor does not have a model name
  * libxfce4panel: Fix memory management of source for menu positioning
  * panel: Delay removal of ExternalPlugin to prevent use-after-free
  * systray: Cancel any async D-Bus operation in finalize()
  * tasklist: Do not try to resolve /proc/pid/exe to launch new instance
  * Translation Updates
* Fri Feb 10 2023 Maurizio Galli <maurizio.galli@suse.com>
- Ensure statusnotifier plugin is fully usable with appindicators
* Thu Feb  9 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.2
  * directorymenu: Add missing sanity check
  * panel: Properly handle null string as property default value
  * Revert "Use RGBA visual only if compositing is enabled (Fixes
    gxo#xfce/xfce4-panel#251)" (gxo#xfce/xfce4-panel#672)
  * Revert "systray: Do not require compositing to be enabled to
    use RGBA visual"
  * systray: Fix blurry icons in prefs dialog when UI scale > 1
  * launcher: Fix blurry icons in prefs and add dialogs when UI
    scale > 1
  * launcher: Use GIcon for the tooltip icon (gxo#xfce/xfce4-panel#674)
  * pager: Use WnckHandle if available (gxo#xfce/xfce4-panel#695)
  * Translation Updates
* Wed Jan 11 2023 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.18.1
  * Update copyright year
  * clock: Add missing sanity check
  * clock: Do not override custom font formats
  * clock: Fix sync timeout
  * docs: Fix version for xfce_panel_set_image_from_source()
  * libxfce4panel: Deprecate XfcePanelImage
  * tasklist: Adapt wnck default icon size when UI scale > 1
    (gxo#xfce/xfce4-panel#681)
  * tasklist: Do not duplicate menu item activation
  * tasklist: Fix group button visibility
  * tasklist: Fix scrolling through window buttons (gxo#xfce/xfce4-panel#692)
  * tasklist: Fix window count positioning when UI scale > 1
  * tasklist: Keep icon pixbuf around and use surface also for menu items
  * windowmenu: Adapt wnck default icon size when UI scale > 1
    (gxo#xfce/xfce4-panel#682)
  * Translation Updates
* Sat Dec 17 2022 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.18.0
  * Bump requirements for Xfce 4.18
  * Translation Updates
* Sun Aug 21 2022 Maurizio Galli <maurizio.galli@suse.com>
- Update to 4.16.5
  * systray: Help to keep status notifiers from vanishing
    (gxo#xfce/xfce4-panel#102,gxo#xfce/xfce4-panel#243, gxo#xfce/xfce4-panel#599)
  * panel: Populate item dialog after setting dialog screen (gxo#xfce/xfce4-panel#62)
  * systray: Perform sanity checks also for "NewStatus" signal (gxo#xfce/xfce4-panel#602)
  * pager: Properly disconnect signal handler
  * tasklist: Guard against null workspace
  * panel: Be sure to save plugins before xfconf_shutdown()
  * tasklist: Fix critical warning when starting on a disconnected device
  * Update `.gitignore`
  * libxfce4panel: Destroy plugin prefs dialog on plugin "destroy" signal
  * build: Fix intltool lock file problem during make distcheck
  * prefs-dialog: Filter out irrelevant selection changes in "Items" tab
  * wrapper: Ensure that provider stays alive when processing "g-signal"
  * Revert "panel: Keep a reference on item during drag and drop"
  * tasklist: Fix wireframe for CSD windows (v2) (gxo#xfce/xfce4-panel#562)
  * Translation Updates
* Sun Apr 17 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 4.16.4
  * Update copyright year and standardize formatting
  * Update and sort author list by name
  * panel: Fix regression "intellihide does not hide when leaving
    slowly" (gxo#xfce/xfce4-panel#388)
  * panel: Fix regression "'Span Monitor' has no effect"
    (gxo#xfce/xfce4-panel#405)
  * panel: Keep a reference on item during drag and drop
  * Fix `core.UndefinedBinaryOperatorResult` warning from
    `scan-build` (gxo#xfce/xfce4-panel#142)
  * panel: Fix broken drag and drop between panels
    (gxo#xfce/xfce4-panel#561)
  * panel: Disconnect from screen signals when window is destroyed
  * systray: Do not connect to proxy signal if async method failed
  * panel: Mitigate a memory leak when removing items
    (gxo#xfce/xfce4-panel!46)
  * windowmenu: Emit "deactivate" signal when hiding the menu
    (gxo#xfce/xfce4-panel#22, gxo#xfce/xfce4-panel!68)
  * systray: Fix wrong sanity check
  * systray: Properly initialize systray item
  * systray: Trust the status to update the attention icon
    (gxo#xfce/xfce4-panel#392, gxo#xfce/xfce4-panel!64)
  * Fixed some window buttons not appearing in the panel
    (gxo#xfce/xfce4-panel#188, gxo#xfce/xfce4-panel!66)
  * launcher: Only activate under mouse (gxo#xfce/xfce4-panel#519)
  * libxfce4panel: Review memory management for context menu
    (gxo#xfce/xfce4-panel#452, gxo#xfce/xfce4-panel!46)
  * actions: Block panel autohide
    (gxo#xfce/xfce4-panel#431, gxo#xfce/xfce4-panel!62)
  * launcher: Clear action menu when destroyed
    (gxo#xfce/xfce4-panel#540, gxo#xfce/xfce4-panel!61)
  * Translation Updates
* Sat May  8 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 4.16.3
  * panel: Change width of default panel-2 to 1%%
    (gxo#xfce/xfce4-panel#454)
  * panel: Fix xfce4-panel-CRITICAL
  * panel: Fix xfce4-panel-CRITICAL when already running
  * libxfce4panel: Do not destroy context menu if popped up
    (gxo#xfce/xfce4-panel#442)
  * launcher: Check for menu item initialization
  * launcher: Fix garcon-CRITICAL at startup
  * systray: Fix GObject-CRITICAL
  * systray: Fix Gtk-CRITICAL at startup/shutdown
  * systray: Fix libsystray-CRITICAL
  * tasklist: Fix Gtk-CRITICAL
  * Silent `-Wcast-align` from Clang
  * Translation Updates
* Sun Feb 28 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 4.16.2
  * Add icons to help and about items in panel menu
  * Modernize documentation (developer.xfce.org)
  * Translation Updates
* Thu Jan 28 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 4.16.1
  * pager: Use gobject bindings (gxo#xfce/xfce4-panel#376)
  * pager: Switch to new workspaces icon name
  * launcher: avoid double fork
  * statustray: Display tooltip title of statusnotifier items as
  * plaintext
  * statustray: Prevent crash when parsing properties
    (gxo#xfce/xfce4-panel#379)
  * windowmenu: fix use-after-free in window_menu_plugin_window_item_new
  * Fix compilation warnings
  * Update `.gitignore`
  * Translation Updates
* Wed Dec 23 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to 4.16.0
  - panel: Fix intellihide with CSD (Fixes gxo#xfce/xfce4-panel#368)
  - tasklist: Fix wireframe for CSD windows (Fixes gxo#xfce/xfce4-panel#338)
  - tasklist: Auto-adjust icon size (Closes gxo#xfce/xfce4-panel#90)
  - Revert "tasklist: Auto-adjust icon size (Closes gxo#xfce/xfce4-panel#90)"
  - Fix GSourceFunc removal
  - Remove GSourceFunc casts
  - Remove GLIB_CHECK_VERSION IFDEFs which are obsolete after glib bump
* Mon Dec 14 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 4.15.6
  * settings: Use spinbuttons for size and nrows
  * settings: Update item listview toolbar
  * Make dbusmenu-gtk3-0.4 optional, disables StatusNotifier integration
  * gobject introspection wants a capital letter for the gir file
  * Use new xfce_spawn API
  * Bump GLib (and gio, gthread, etc) minimum to 2.50.0
  * Update .gitignore
  * Add README.md to EXTRA_DIST
  * Fix compiler warnings
  * Fix memory leaks
  * Drop generated code from repo
  * Revert "launcher: Appear "checked" on click
    (gxo#xfce/xfce4-panel#256)"
  * Translation Updates
- Rename typelib subpackage to match gir name
- Fix files listed twice warning
* Fri Nov 20 2020 Maurizio Galli <maurizio.galli@gmail.com>
- We need to make sure xfce4-statusnotifier-plugin-lang is also
  removed or it creates dependency conflicts.
* Wed Nov 11 2020 Maurizio Galli <maurizio.galli@gmail.com>
- xfce4-statusnotifier-plugin is now obsolete because directly
  integrated into xfce4-panel.
* Tue Nov  3 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 4.15.5
  * actions: Switch to new session icons (gxo#xfce/xfce4-panel#332)
  * add-items: Drop not-so-helpful dialog subtitle
  * add-items: Bump default dialog size (gxo#xfce/xfce4-panel#258)
  * launcher: Appear "checked" on click (gxo#xfce/xfce4-panel#256)
  * tasklist: Limit blinking notification
  * intellihide: Check if cursor is over the panel
    (gxo#xfce/xfce4-panel#311)
  * launcher: Set plugin icon as fallback (gxo#xfce/xfce4-panel#329)
  * Add new README.md
  * Fixed icon for about dialog and added more icons for better scaling
  * Unref datetime objects
  * Translation Updates
* Fri Aug 28 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 4.15.4
  * New plugin: statustray (supports statusnotifier and systray)
  * plugins: Add new rDNS icons for all plugins
  * Use shared field codes expansion
  * tasklist: Add "Launch New Instance" item to menu
    (gxo#xfce/xfce4-panel#158)
  * Add new app icon and rDNS icon name
  * Fix background of 48px app icons (bxo#16873)
  * dark-mode: Make property unique across panels
  * tasklist: Allow keyboard navigation within groups
    (gxo#xfce/xfce4-panel#270)
  * applicationsmenu: Correctly block autohiding
    (gxo#xfce/xfce4-panel#287)
  * action buttons: Fix combobox signal
  * action buttons: Drop 'inverted buttons' setting (#223)
  * action buttons: Add button title options (bxo#8980)
  * action buttons: Fix separator width (bxo#15558)
  * launcher: Fix launcher menu button state
    (gxo#xfce/xfce4-panel#264)
  * launcher: Fix crash with actions menu (bxo#16823)
  * launcher: Fix in default panel configuration
  * Improve docs for xfce_panel_plugin_position_widget (bxo#9438)
  * Add Gio to libxfce4panel gir includes
  * Fix panel build with vala 0.48 (bxo#16426)
  * Update gitignore (gxo#xfce/xfce4-panel#295)
  * Drop references to Gtk2 and 4.6 panel plugins
  * panel: Improve autohide animation
  * panel: Add "popdown-speed" property to adjust autohide animation
  * panel: Fix autohide state machine
  * panel: Fix cancellation of autohide animation
  * panel: Immediately show panel in intellihide
  * panel: Don't tamper with leave_opacity value (bxo#16296)
  * launcher: Show desktop actions in context menu
  * plugin: Show custom menu items below plugin name
  * tasklist: Hide brackets for min windows by default
  * tasklist: Fix crash middle-click-closing grouped windows
    (bxo#16410)
  * systray: Basic support for symbolic icons
  * systray: Silence deprecation warnings
  * systray: Remove superfluous warning
  * Improve wording in "Remove plugin" dialog (bxo#9000)
  * settings: Add keywords for discoverability (bxo#10694)
  * Fix GTimeVal deprecation (bxo#16643)
  * Fix memory leak in panel plugin wrapper (bxo#16640)
  * Update docstring
  * Update libxfce4panel symbols
  * Make var names more consistent
  * Enable dark-mode by default
  * tic-tac-toe: Fix XfceTitledDialog with CSD
  * add-item dialog: Fix XfceTitledDialog with CSD
  * systray: Improve app icon lookup
  * directorymenu: Add create folder/document menuitems (bxo#15639)
  * directorymenu: Add option to hide folder/terminal menuitems
    (bxo#15630)
  * plugins: Fix enter/leave opacity w/o compositing (bxo#14577)
  * clock: Drop leading zeros for days in default layout
  * clock: Add back hour:min to format presets (bxo#16035)
  * panel: Make sure "span monitors" is conditionally sensitive
  * tasklist: Fix drag&drop in deskbar mode (bxo#16298)
  * Fix autohide with bg color or image (bxo#16064)
  * Improve the marching ants animation
  * Remove extra underscore (bxo#16266)
  * Use an empty placeholder icon for launcher (bxo#15819)
  * Always provide files for vala binding in dist tarball
  * Replace GtkStock icon
  * Use symbolic window-close button image
  * Drop support for Gtk2 and 4.6 plugins
  * Drop Gtk2/4.6-only references from the docs
  * Don't show or try to load Gtk2 plugins anymore
  * Add dark mode preference
  * autohide: Add sliding out animation
  * Draw panel border based on position and length
  * appmenu: Listen to icon theme changes (bxo#15861)
  * appmenu: Use panel's icon size
  * clock: Validate timezone entry (bxo#16036)
  * prefs: Plug memory leaks (bxo#16016)
  * docs: Fix build by dropping unused refs (bxo#16031)
  * pager: Fix scrolling in pager-buttons (bxo#15614)
  * pager: Face-lift of settings dialog
  * pager: Only show scroll-option with buttons
  * pager: Add option to show workspace number
  * systray: Drop "Show frame" option (bxo#14186)
  * tasklist: Resize when windows get removed (bxo#14394)
  * systray: Fix icons without compositing (bxo#14577)
  * windowlist: Make layout consistent with xfdesktop
  * windowlist: Replace deprecated gtk_widget_modify_font
  * launcher: Fix visual state of arrow-button (bxo#15818)
  * launcher: Avoid excessive left padding on popup menu
    (bxo#15819)
  * Fix typos and improve code formatting
  * Translation Updates
- Remove systray-symbolic-icons.patch
* Wed Apr 29 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 4.14.4
  * Fix panel build with vala 0.48 (bxo#16426)
  * Fix memory leak in panel plugin wrapper (bxo#16640)
  * tasklist: Fix crash middle-click-closing grouped windows
    (bxo#16410)
  * panel: Make sure "span monitors" is conditionally sensitive
    (bxo#15169)
  * Translation Updates
* Sun Mar 22 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Added systray-symbolic-icons.patch. Backport to enable symbolic
  icons in systray
* Mon Jan 13 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to 4.14.3
  * Always provide files for vala binding in dist tarball
- Changes from 4.14.2
  * plugins: Fix enter/leave opacity w/o compositing (bxo#14577)
  * tasklist: Fix drag&drop in deskbar mode (bxo#16298)
  * appmenu: Use panel's icon size
  * appmenu: Listen to icon theme changes (bxo#15861)
  * prefs: Plug memory leaks (bxo#16016)
  * Replace GtkStock icon
  * Translation updates
* Thu Sep 26 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 4.14.1
  * Draw panel border based on position and length
  * windowlist: Make layout consistent with xfdesktop
  * windowmenu: Replace deprecated gtk_widget_modify_font
  * tasklist: Resize when windows get removed (bxo#14394)
  * systray: Fix icons without compositing (bxo#14577)
  * pager: Fix scrolling in pager-buttons (bxo#15614)
  * launcher: Fix visual state of arrow-button (bxo#15818)
  * launcher: Avoid excessive left padding on popup menu (bxo#15819)
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Mon Aug 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.14.0
  * tasklist: Keep panel visible on drag and drop (bxo#15703)
  * pager: Keep panel visible on drag and drop (bxo#15703)
  * launcher: Make dialog's context menu popup at pointer
  * Make strings translatable
  * Translation Updates
- Cleaned up spec file
* Sun Jul 28 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.13.7
  * Make vala and gobject-introspection optional
  * clock: Add short weekday to default clock string
  * clock: Add date to default clock layout (bxo#15456)
  * prefs: Improve position of panel profiles button (bxo#15657)
  * tasklist: Fix position of group indicator in vertical mode
  * tasklist: Fix overlapping vertical window titles (bxo#14901)
  * tasklist: Add fallback for missing window icons (bxo#15511)
  * directory-menu: Use natural order for sorting (bxo#15413)
  * arrow-button: Remove timeout on dispose (bxo#15696)
  * pager: Ensure bg color is set correctly (bxo#15690)
  * show-desktop: Toggle also when DND-ing (bxo#15654)
  * tic-tac-toe: Add mnemonic to Close button
  * tic-tac-toe: Avoid use-after-free/double-free (bxo#15649)
  * Translation updates
* Sun Jun 30 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.13.6
  * Update default panel layout
  * Retain original GDK_CORE_DEVICE_EVENTS setting for plugins
    (bxo#15044)
  * directorymenu: Fix plugin menu autohide behaviour
  * prefs: Add missing mnemonic accelerators (bxo#15652)
  * prefs: Improve window title (bxo#15653)
  * prefs: Correct capitalization of labels (bxo#15651)
  * arrow-button: Allow connect_after signals on draw
  * tasklist: Draw grouped windows count indicator (bxo#10844)
  * tasklist: Only base bg color of group indicator on Gtk theme
  * tasklist: Avoid draw signal loop
  * tasklist: Don't show actionsmenu in grouped windows
    (bxo#15622)
  * Add more accelerators to dialog buttons (bxo#15490)
  * AC_CONFIG_MACRO_DIR -> AC_CONFIG_MACRO_DIRS
  * Fix typo in debug output
  * Translation updates
* Fri May 17 2019 Vinzenz Vietzke <vinz@vinzv.de>
- Update to version 4.13.5
  * Bugfixes:
  - Revert "Applications menu icon sizing fixes" (bxo#14976)
  - Make sure panel plugin icons aren't clipped (lp#1756608)
  - actions: use a different icon for hybrid sleep when possible
  (bxo#15204)
  - Fix compiler error -Wcast-function-type (GCC 8)
  - Fix alpha-transparent background images (bxo#14850)
  - Fix this use of "defined" may not be portable
  - Bump glib version to 2.42.0
  - tasklist: Activate parent windows (bxo#15307)
  - launcher: Fix tooltip icon size (bxo#15319)
  - Hide systray frame in default panel config
  - separator: Use symbolic icon for more clarity (bxo#15359)
  * Translation updates
* Sat Apr 27 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.13.4
  * Add per-panel setting "icon-size"
  * Set minimum Gtk+3 version to 3.22
  * Bugfixes:
  - Gtk+ deprecation fixes (all plugins)
  - tasklist: Fix group-button states
  - libxfce4panel: arrow button size fixes
  - launcher: plugin sizing fixes
  - appmenu: Add support for other menu editors (bxo#11684)
  - tasklist: Fix urgency blinking for group buttons (bxo#6904)
  - tasklist: Add 'group-button' styleclass
  - Fix anchors for gtk_menu_popup_at_widget (bxo#14803)
  - Fix struts on the bottom and right of the screen (bxo#14886)
  - tasklist: Don't listen for monitor changes in the plugin (bxo#10725)
  - tasklist: Use Gdk to to determine which monitor contains a window
  - tasklist: Ensure pressed buttons with open menus
  - tasklist: Replace exo-lucency with gtkcss
  - tasklist: Make all-minimized group buttons translucent (bxo#10862)
  - tasklist: Switch from wnck* icons to standard names
  - tasklist: Keep groupbutton active after closing menu
  - tasklist: Make sure icons in the group menu are 16px
  - tasklist: Make grouped buttons active (bxo#9129)
  - launcher: Rely on icon-size provided by panel
  - Prevent crash on removing certain plugins (bxo#14418)
  - Add "configure" button to composited infobar
  - Make compositor info in settings dialog a GtkInfoBar
  - directorymenu: Fix crash and drop deprecated call
  - Fix unreadable panel items without compositing (bxo#14842)
  - launcher: Fix arrows not being shown (bxo#14373)
  - launcher: Fix tooltip icon size (bxo#14774)
  - Re-introduce button images to plugin settings dialogs
  - Make the settings dialog more HIG compliant
  - launcher: Add 'New Link' button to properties (bxo#14855)
  - Drop the panel's welcome dialog (bxo#14388)
  - clock: Resolve deprecations and fix binary clock
  - Workaround for xinput2's subpixel handling (lp#1795135)
  - Ensure the orientation style classes are always applied
  - Add orientation-related style classes for improved theming
  - actions: Add support for dm-tool
  - panel-window: set struts with monitor scaling
  * Translation updates
- Changes from 4.13.3
  * Bugfixes:
  - Get the actual widget state flags to avoid constant redraws (bxo#14307)
  - launcher: Fix empty button in remove launcher dialog (bxo#13962)
  - launcher: Make sure icons are not oversize
  - launcher: Make sure the appropriate icon size is used
  - launcher: Fix resizing of pixbuf based icons (bxo#14138)
  - Move "Separator" to the top of the "Add New Items..." menu (bxo#14086)
  - Make a couple of strings translatable (bxo#14338)
  - Make former GtkStock dialog buttons translateable (bxo#14338)
  - Make double-click add plugin in the "Add item" dialog (bxo#9784)
  - clock: Improve discoverability of tooltip help-texts (bxo#11708)
  - Correctly initialize return value (bxo#10873)
  - Gtk+3 fixes:
  - Fix various warnings with Gtk3 (bxo#14135)
  - Fix Gtk+3 version in ifdef
  - Use 'gdk_screen_is_composited' with Gtk3 (bxo#14128)
  - Try to fix menu positioning with Gtk3.22
  - Various icon fixes:
  - Switch to GtkIconTheme (bxo#14125)
  - Fix missing icons with Adwaita icon theme (bxo#14133)
  - Fix remaining deprecated icon names
  * Translation updates
- Changes from 4.13.2
  * Add support for gobject-introspection (Vidar Haarr)
  * Bugfixes:
  - actions: Fix GPtrArray usage (bxo#13981)
  - actions: Show Hybrid Sleep option (bxo#12771)
  - clock: Fix invalid datetime formats appearing in list (bxo#11527)
  - clock: Use freedesktop.org compliant icon (bxo#13779)
  - clock: Add a validator for digital custom formats (bxo#11527)
  - clock: Fix format validation (bxo#11527)
  - launcher: Fix custom images
  - tasklist: Fix scrolling to cycle through open windows (bxo#13789)
  - tasklist: Define cosmetic default padding for images (bxo#13865)
  - tasklist: Fix alignment of labels when orientation is changed (bxo#13864)
  - tasklist: Allow to hide label decorations (bxo#10546)
  - systray: Fix crash when systray is empty (bxo#13927)
  - systray: Don't lookup hash table for null keys (bxo#11929)
  - systray: Add option to display icons with square sizing (bxo#12093)
  - Pass socket id to D-Bus service to embed settings window (bxo#13854)
  - Make "Automatic" the default selection in the panel config dialog
  - Fix make distcheck (But #14040)
  - Improve gtkdoc
  * Translation updates
- Changes from 4.13.1
  * Port to GDBus (Ali)
    This means the panel now depends on xfconf 4.13 - recommended is 4.13.3.
  * Features:
  - systray: Allow ordering of items (bxo#11929)
  - tasklist: Add styleclass to make life easier for themers
  * Bugfixes:
  - Fix DND between external plugins (bxo#13687)
  - Fix drag and drop for internal plugins (bxo#13642)
  - Correct enter and leave opacity label positions (bxo#13594)
  - Fix Gtk3 XfceArrowButtons not blinking (bxo#13599)
  - Fix datarootdir declaration in .pc files (bxo#13589)
  - Use fd.org terminal icon name (bxo#13592)
  - Don't let the wrapper crash on unknown properties (bxo#13614)
  - Set default panel-2 size of default settings
  - windowmenu: Fix icon size in menu
  - systray: Fix alignment of single non-square items (bxo#9095)
  - clock: Make the default date and time format translatable (bxo#9637)
  * Translation updates
  Changes from 4.13.0
  * Port to Gtk3:
    The port is the result of the hard work Nick, Peter, Andrzejr, Simon and
    many others that helped with testing, patches and translations.
  * Features:
  - Support for the "primary" monitor option in RandR
  - Gtk2 plugins are still supported and work almost completely fine
    (see regressions below)
  * Deprecations:
  - xfce_panel_image is deprecated, instead plugins shall use GtkImage and
    xfce_panel_plugin_get_icon_size which introduces defined icon size-steps
    to avoid fuzzy icons
  * Known regressions:
  - The panel is not visually focused by default (fixed in Xfwm4>=4.12.4)
  - Moving panel plugins via drag and drop on the panel directly via the plugins
    context menu action "Move" is currently broken (works fine in preferences dialog)
  - Small regression with intelligent hiding (when opening a menu, the panel
    hides and comes back immediately while it should just remain visible)
  - Enter/leave opacity does not work for Gtk2 plugins
  - Not all panel settings may be kept as the configuration is not 100%% backward
    compatible (e.g. we're using GdkRGBA instead of GdkColor for the backgorund)
  * Known todos:
  - Fix all bugs/regressions
  - Remove more/all Gtk+ deprecations
    (lots of warnings when compiling currently)
  * Lots of translations updates
- Clean up spec file and dropped obsolete macros
- Added conditional %%bcond_with git for easier maintanance when using
  git master branch
* Mon Jan  7 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Drop hard dependency of xfce4-panel-restore-defaults (boo#1120913)
* Mon Dec 17 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Added subpackage for script to restore panel defaults
  https://lists.opensuse.org/opensuse-xfce/2018-12/msg00014.html
* Mon Feb 26 2018 crrodriguez@opensuse.org
- Add explicit buildrequires on: pkgconfig(atk), pkgconfig(dbus-1)
  pkgconfig(pango), pkgconfig(x11), pkgconfig(xext) all direct
  dependencies not mentioned in spec file.
* Mon Dec 18 2017 seife+obs@b1-systems.com
- update to version 4.12.2
  - Feature: Support for RandR's "primary monitor"
  - Translation updates
* Sat Nov 26 2016 seife+obs@b1-systems.com
- update to vesion 4.12.1
  - maintenance release.
  - translation updates.
  - Clock: fixed compiler warnings.
  - Preferences: support for xfpanel-switch (if installed).
  - DirectoryMenu: fixed bugs bxo#10331 and bxo#11742
  - Tasklist: fixed background color issue.
  - ApplicationsMenu: fixed uninitialized variable.
  - make distcheck fix/workaround.
* Sat Feb 28 2015 gber@opensuse.org
- update to version 4.12.0
  - actions: Use localization for confirmation dialog titles
    (bxo#11949)
  - use actual output geometry to place panels (bxo#11058)
  - tasklist: Fix grouped icons sometimes are wrongly rendered as a
    mini-icon (bxo#10846)
  - actions: Use common icon names (bxo#11513)
  - pager & tasklist: Disabled wrapping when scrolling (bxo#6401)
  - clock: Prevent recursion of symlinks
  - make panel hide intelligently with shaded windows (bxo#11371)
  - translation updates
- drop obsolete xfce4-panel-fix-icon-name.patch
- Drop xfce4-panel-fix-action-button-saving-session.patch: fixed
  upstream.
* Mon Jan  5 2015 gber@opensuse.org
- add xfce4-panel-fix-action-button-saving-session.patch in order
  to fix the action button logout session saving logic (bxo#7930,
  backported from upstream git)
* Mon Jan  5 2015 gber@opensuse.org
- update to version 4.11.2
  - Added intelligent panel hiding (JPohlmann, ochosi)
  - Action buttons: only save session when requested (bxo#7930)
  - Translation updates
* Mon Jun 23 2014 gber@opensuse.org
- update to version 4.11.1
  - Action Buttons: Fix panel autohide (bug #8960) (Petr Gajdusek)
  - Applications Menu: fixed incorrect initial icon size in some
    Gtk themes
  - Window Buttons: fixed rendering of minimized window buttons
  - Applications Menu: changed default button title to
    "Applications"
  - Window Buttons: wrap windows when scrolling through window list
    (Andre Miranda)
  - libxfce4panel: preserve ArrowButton relief during blinking
  - Window Buttons: prevent several buttons to be selected at once
  - Action Buttons: default to a horizontal button layout in the
    deskbar mode
  - Translation updates
- drop obsolete xfce4-panel-fix-actions-autohide.patch
* Wed Apr 30 2014 gber@opensuse.org
- update to version 4.11.0
  - Window Buttons: Improve the tasklist multimonitor handling
  - Scroll the items list in the config dialog box (bug #10582)
  - Set EWMH client type to WNCK_CLIENT_TYPE_PAGER (bug #10508)
  - Fixed transparency issues with Gtk3 plugins
  - Workspace Switcher: fixed aspect ratio in deskbar mode
  - Added --enable-gtk3 configure flag. Note: it produces gtk2/gtk3
    versions of libxfce4panel and wrapper binary so that both gtk2
    and gtk3 plugins can be embedded. The panel and stock plugins
    are still using gtk2.
  - Applications Menu: Use new GarconGtkMenu
  - Window Buttons: middle-click action configurable (nothing,
    close, minimize)
  - Drectory Menu: Pass path to argument (bug #10270)
  - Window Buttons: close a window on middle click (bug #8096)
  - Applications Menu: support for non-square icons and layout
    fixes
  - Install XfcePanelPlugin properties at once
  - Clock: added support for timezone selection
  - Put each window in a new window group
  - Window Buttons: Show urgent windows from other workspaces
    (bug #5167)
  - Clock: calendar popup
- drop obsolete xfce4-panel-add-calendar-popup.patch
- add libxfce4panel-2_0-4 subpackage with the GTK 3 variant of the
  xfce4-panel library
* Wed Oct  2 2013 gber@opensuse.org
- add xfce4-panel-fix-actions-autohide.patch in order to fix
  autohiding after using the actions plugin menu (bnc#764310,
  bxo#8960)
* Sun May  5 2013 gber@opensuse.org
- update to version 4.10.1
  - bugfix in icon/pixbuf resizing code
  - fix icons not probably resizing when requested
  - autotools updates
  - ignore GVarueArray compiler warning
  - use G_ENABLE_DEBUG to set fatal messages
  - fixed DnD markers with non-square small items
  - actions: Fix logic of session saving
  - panel: Emit save signal for plugins
  - libxfce4-panel: Fix typo in the API docs
  - translation updates
* Thu May  2 2013 gber@opensuse.org
- own %%{_datadir}/xfce4
* Tue Jul 24 2012 gber@opensuse.org
- added xfce4-panel-add-calendar-popup.patch which adds a calendar
  popup to the clock plugin (bnc#767145, bxo#9034)
* Sun Apr 29 2012 gber@opensuse.org
- update to version 4.10.0
  - use correct LGPL licenses in the libs
  - restore child properties when moving a plugin
  - migrate: use correct pointer for action migrate
  - migrate: don't try to migrate already migrated plugin
  - translation updates
- add dependency on exo-tools since it uses exo-open to launch
  applications in a terminal
* Fri Apr 27 2012 gber@opensuse.org
- add dependency on libgarcon-data which provides the menu data
* Thu Apr 19 2012 gber@opensuse.org
- obsolete xfce4-panel-doc properly
* Sat Apr 14 2012 gber@opensuse.org
- update to version 4.9.2
  - Launcher: fix desktop file monitoring on some systems
  - Panel: improved DnD markers
  - Panel: fix invalid autohide with socket dialog
  - Panel: remove duplicated function
  - Panel: remove duplicated function
  - Actions: show translated strings
  - Actions: fix mnemonics conflict
  - Clock: fix compiler warning
  - Bump version-info of libxfce4panel
  - Translation updates
* Fri Apr 13 2012 gber@opensuse.org
- added xfce4-panel-fix-icon-name.patch which fixes an icon naming
  inconsistency
* Sun Apr  8 2012 gber@opensuse.org
- update to versio 4.9.1
  - Panel: don't destroy window when focussed and Alt+F4 is pressed
  - Panel: use new help function to redirect to docs.xfce.org
  - Docs: remove mallard documentation
  - Docs: don't install the gtkrc README
  - Clock: don't use sigval_t
  - Panel: add support for pluggable dialogs
  - Panel: save changed plugin ids if a plugin failed to load
  - Directorymenu: fix prefered app not working without snotify
  - Launcher: small=FALSE in deskbar mode with label visible
  - Actions: limit size of action buttons to row size
  - Panel: removed item size checks
  - Clock: fixing clock orientation in vertical/deskbar mode
  - Pager: fixing infinite loopin in the WNCK pager aspect ratio
    workaround
  - Pager: fixing plugin->size updates
  - Pager: fixed workspace ordering in the vertical mode
  - Pager: workaround for aspect ratio error in WNCK pager in
    deskbar mode
  - Pager: changing orientation depending on the panel mode
  - Clock: changing default value of rotate-vertically to TRUE
  - Pager: fixed preprocessor macro
  - Pager: removing broken workaround for aspect ratio in deskbar
    mode
  - Pager: making use of a fixed libwnck version (>=2.31.0)
  - revert "Use realtime POSIX timers for the clock."
  - revert "Clock: Don't use sigval_t (bug #8297)."
  - Launcher: show the desktop file in the tooltip
  - Panel: make string in about translatable
  - Panel: don't ask for panel when inserting items
  - Panel: reply to the caller for plugin events
  - Applicationsmenu: fall-back to xfdesktop for
    xfce4-popup-applicationsmenu
  - Applicationsmenu: recurse application menu selection-done
    gignal
  - Panel: add (un)lock option to panel menu
  - Panel: add confirmation before creating launchers from dnd
  - Applicationsmenu: allow non-squared icons in applications
    button
  - Panel: save plugin-ids when removing and moving items in ed
  - Tasklist: bringing back 4.8 max-button-size property
  - Tasklist: capping buttons height when button labels are
    visible
  - Tasklist: reverting "ceil" to "floor" (as in 4.8)
  - Actions: query visibility and save as strings
  - Panel: add option in preferences dialog to disable struts
  - Showdesktop: allow middle-click to shade windows
  - Panel: add style property to control size of autohide window
  - Panel: make compositing settings insensitive
  - Tasklist: add option to disable mouse scrolling
  - Tasklist: make the plugin shrink instead of expand
  - drop AC_PROG_LIBTOOL and AC_DISABLE_STATIC for LT_PREREQ and
    LT_INIT
  - Clock: use realtime POSIX timers for the clock
  - Actions: merge functionality of xfce4-session plugin
  - Applicationmenu: show menu on button-press-event
  - Migrate: add version based config migration
  - Clock: fix typo in tooltip
  - General: add deskbar mode and nrows property to plugins
  - General: add small property for plugins
  - Separator: remove new line option
  - General: make plugins work with deskbar mode and small property
  - Panel: change drop highlighting to a red line
  - Applicationmenu: reload menu on directory changes
  - Panel: make sure the panel has a position on startup
  - Panel: work with a unique id for each panel
  - Panel: remove autosaving on exit and with timeout
  - Panel: only save what is required and when needed
  - Docs: update to latest version
  - translation updates
- dropped obsolete xfce4-panel-fix-terminal-invocation.patch
* Wed Apr  4 2012 gber@opensuse.org
- simplify libXext-devel dependency
- fix missing icon
* Sat Mar 24 2012 gber@opensuse.org
- correct build dependencies
- specfile cleanup
- split off -lang subpackage
- added xfce4-panel-fix-terminal-invocation.patch in order to fix
  the invocation of a terminal emulator by the directory menu
  plugin (bxo#8018)
* Mon Feb 20 2012 gber@opensuse.org
- add dependency on libXext-devel
* Thu Oct 20 2011 gber@opensuse.org
- install helper binaries into %%{_libexecdir}/xfce4-panel
- install HTML documentation under
  /usr/share/xfce4/xfce4-panel/html
- split off -doc subpackage
- make the file list a bit more explicit
* Wed Sep 21 2011 gber@opensuse.org
- update to version 4.8.6
  - Systray: Control the thickness of the frame
  - Panel: Print string in case of an invalid position
  - Libxfce4panel: Always try to return an icon
  - Directorymenu: Also send the target directory as arg
  - Bugfixes
  - Translation updates
- dropped obsolete
  xfce4-panel-4.8.5-fix-crash-on-non-existing-menu.patch,
  xfce4-panel-4.8.5-handle-panel-not-yet-realized.patch,
  xfce4-panel-4.8.5-wait-until-wm-is-ready.patch
* Tue Sep 20 2011 gber@opensuse.org
- renamed xfce4-panel-4.8.-wait-until-wm-is-ready.patch to
  xfce4-panel-4.8.5-wait-until-wm-is-ready.patch
- added xfce4-panel-4.8.5-handle-panel-not-yet-realized.patch
  in order to handle the case when the panel is not yet realized
  (backported from upstream git)
- added xfce4-panel-4.8.5-fix-crash-on-non-existing-menu.patch in
  order to fix a segfault with not-existing menus (backported from
  upstream git)
* Sun Jul 10 2011 gber@opensuse.org
- added xfce4-panel-4.8.-wait-until-wm-is-ready.patch which makes
  the panel wait until the wm is ready on all screens in order to
  ensure that it ends up on the correct screen in multipanel setups
* Tue Jun 21 2011 gber@opensuse.org
- update to version 4.8.5
  - tasklist: avoid unneeded dnd actions
  - tasklist: allow both motion activation and dnd
  - panel: make preferences dialog work in Gtk+ 2.24.5
  - systray: add xfpm to known apps for a decent icon
  - tasklist: drop Gtk 2.22 API
  - bugfixes
  - translation updates
* Sun Jun 19 2011 gber@opensuse.org
- update to version 4.8.4
  - update online documentation help location
  - improved thread-safety
  - idle XfcePanelImage loading
  - make the pager message less scary
  - add a sorting mode for tasklist reordering with dnd
  - bugfixes
  - translation updates
* Wed Apr  6 2011 gber@opensuse.org
- update to version 4.8.3
  - use portable abicheck.sh from xfconf
  - bugfixes
  - translation updates
* Fri Apr  1 2011 gber@opensuse.org
- update to version 4.8.2
  - change packing order of buttons in pager to match wnck
  - set some atk object names on panel buttons without label
  - allow installation of the helpers in a custom location
  - set a static role for the panels (bxo#7094), reverted the
    previous fix
  - ask to start the panel if 'xfce4-panel -r' is called without
    instance
  - respawn a child if the plugin was realized with a pid
  - use the widget snapshot as tasklist draw icon.
  - bugfixes
  - translation updates
- dropped obsolete
  xfce4-panel-4.8.1-fix-install-documentation.patch
* Fri Feb 18 2011 gber@opensuse.org
- call %%desktop_database_post/un
- call %%icon_theme_cache_post/un
* Sat Feb 12 2011 gber@opensuse.org
- added xfce4-panel-4.8.1-fix-install-documentation.patch which
  fixes a bug in the build system that prevented the HTML
  documentation from getting installed (bxo#7274)
- remove libtool files
* Thu Feb  3 2011 gber@opensuse.org
- update to version 4.8.1
  - bugfixes
  - translation updates
  - improved debug messages
* Mon Jan 17 2011 gber@opensuse.org
- provide %%{_datadir}/xfce4/panel-plugins in order to remain
  backwards-compatible with all external panel plugins
* Mon Jan 17 2011 gber@opensuse.org
- corrected summary
- updated to version 4.8.0
  - restart systray manager on compositing changes
  - added debugging information
  - bugfixes
* Mon Dec 27 2010 gber@opensuse.org
- remove unsupported locales
- improved descriptions/summaries
- do not install empty README, TODO
- corrected group
- corrected license
- moved API documentation to -devel subpackage
* Wed Dec 15 2010 prusnak@opensuse.org
- fix filelist
* Sun Dec  5 2010 prusnak@opensuse.org
- update to 4.7.6
  - Always use applications menu for default menu.
  - Fix Exec key in desktop file handler (bug #6912).
  - Fix if statement in xfce_tasklist_button_visible().
  - Depend on garcon 0.1.4.
* Wed Dec  1 2010 prusnak@opensuse.org
- use pkgconfig symbol in BuildRequires
* Sun Jul 18 2010 bernhard@bwalle.de
- updated to 4.6.4
  o Destroy windowlist menu in an idle (bug #3853).
  o Link directly to libm (bug #6233).
  o Allow compilation with exo-1 too.
  o Translation updates (ru, ta, pr_BR, hu, gl, fi, it, si, uk, id, ug).
* Thu Mar 18 2010 prusnak@suse.cz
- build branding subpackage as noarch
* Wed Jan 13 2010 prusnak@suse.cz
- updated to 4.6.3
  - Don't use g_object_set in the init function (bug #6110).
  - Translation updates (nn, nl, sv, kk, gl, sk, eu, sk, cs, zh_CN).
* Wed Nov 11 2009 prusnak@suse.cz
- updated to 4.6.2
  - Properly set orientation of tasklist handler (bug #5222).
  - Fix launcher with 'Run in Terminal' (part of bug #5301).
  - Fix typo preventing build on older gtk versions.
  - Don't send -r to session restart command (bug #5454).
  - Add dist-hook: all to the API docs Makefile.am as well.
  - Add dist-hook: all to the libxfce4panel/ Makefile.am.
  - Add missing translation.
  - Merge translation from master back to xfce-4.6.
  - Remove unused code.   Nick Schermer   1       -2/+1
  - Add option to tasklist to force a fixed width (bug #5045).
  - Get the time the same as orange does, hopefully should fix bug #5352.
  - Better check for the lcd resize when the number of hour digits changes (bug #5218).
  - Use g_timeout_add_seconds when available for the clock timeout.
  - Resync tooltip and clock timeout when they are out of sync (bug #2957).
  - Remove the hour interval from the clock, minutes are good enough.
  - Use Git in the build files and drop unneeded po files.
  - Use g_markup_printf_escaped in the launcher tooltip (bug #5507).
  - A whole bunch of translation updated (tr, pt, ca, ja, es, da, gl, sq, lv, sk, ru,
    el, gl, kk, hu, eu, ast, ro)
* Fri Aug 14 2009 puzel@novell.com
- add libexecdir/xfce4 directory to filelist so that
  xfce4-panel-plugins could use it
* Tue Apr 21 2009 prusnak@suse.cz
- updated to 4.6.1
  - Migrate launcher category icons from 4.4 panels (bug #5067).
  - Fix compilation with -Wl,--as-needed (bug #5103).
  - Don't crash when the quit action button is pressed (bug #5118).
  - Properly set the systray orientation property (bug #5149).
  - Fix xfce-hvbox not working with gtk 2.16 (bug #5166).
  - Don't crash the launcher plugin when the launcher entry list is empty.
  - Add icon-name fallback to the show desktop plugin (bug #5117).
  - Disconnect the icon theme changed signal from a launcher when it
    is destroyed to avoid crash when the icon theme changes.
  - Fix drawing dots mode of the seperator plugin in a vertical panel (bug #5162).
  - Fix a possible crash when setting the session restart style on an
    uninitialized client session.
  - A whole bunch of translation updated (pl, es, pt, ja, es, gl, nb, pt_PT).
* Mon Mar 16 2009 prusnak@suse.cz
- moved branding files to branding-upstream subpackage
* Fri Feb 27 2009 prusnak@suse.cz
- updated to 4.6.0 (Xfce 4.6.0 release)
* Wed Oct 29 2008 bwalle@suse.de
- update to 4.4.3
  o Quite a bit code changed in the dnd code. Mostly to fix a
    segfault in FreeBSD-amd64, but more problems were discovered
    and a lot of code was simplified.
  o Don't respond the uri drags, we don't use it and it only causes
    problems like hiding the panel when a file was dragged over the
    panel.
  o Fix crash with xrandr 1.2
* Mon Dec  3 2007 bwalle@suse.de
- update to 4.4.2
  o Fix window manager hints reporting width 1 pixel too wide
  o Improve MCS plugin code.
  o Fix expansion of items a non-full-width panel.
  o Make sure tooltips are set for more than 1 clock instance
  o Fix area that is off-limits to other windows (_NET_WM_STRUT
    hints) for a Xinerama setup with differently sized monitors
  o Fix loading internal plugins if a similar file exists in the
    start directory
  o Only update the clock once a minute when seconds are disabled.
    The digital clock is also set in the default layout to minimize
    the amount of screen updates.
  o Fix possible buffer overflow in launcher tooltips
  o Use exo-open --launch TerminalEmulator in the default
    configuration
  o Fix crash when removing a panel in Gtk+ 2.11.x
  o Remove trailing parens on AC_INIT version info to work around bug
    in intltool 0.35.x and 0.36.x.
  o Updated and new translations
* Wed Sep  5 2007 prusnak@suse.cz
- fix crash when removing panel [#302058] (panel_remove.patch)
* Tue Aug 28 2007 prusnak@suse.cz
- fixed Obsoletes (added < 4.4.0)
* Wed Aug 15 2007 prusnak@suse.cz
- Provides and Obsoletes xfce4-panel-plugins [#298863]
* Tue Aug 14 2007 prusnak@suse.cz
- fixed last commit (moved .so plugins back to base package)
* Mon Aug  6 2007 pnemec@suse.cz
- move some libraries and gtk-doc into -devel subpackage [#248813]
* Wed Jun 20 2007 prusnak@suse.cz
- added libxfce4util-devel to Requires of -devel subpackage
- use %%find_lang
* Tue Apr 10 2007 bwalle@suse.de
- update to 4.4.1
  o Completely hide the right-click menu when kiosk mode is
    enabled.
  o Show the system tray border in the default layout and increase
    the top panel size to 30px, so users can actually see the
    system tray.
  o Allow freely movable panels on the screen edges.
  o Improve the icon size of the actions plugin and add an option
    to change the orientation of the buttons.
  o Unhide when dragging over the panel.
  o Check for NULL pointers in DBG messages to prevent crashes on
    Solaris, based on patch from William Bonnet.
  o Add some checks for valid tree selection.
  o Many translation updates.
* Thu Jan 25 2007 bwalle@suse.de
- updated to 4.4.0
* Sat Nov  4 2006 bwalle@suse.de
- updated to 4.3.99.2 (4.4 rc2)
* Mon Sep  4 2006 pnemec@suse.cz
- updated to new version 4.3.99.1
* Fri Aug 25 2006 bwalle@suse.de
- added startup-notification-devel as BuildRequires
* Wed Aug 23 2006 pnemec@suse.cz
- added dbus-devel to build requires
* Tue Aug  1 2006 pnemec@suse.cz
- initial comment, version is 4.3.90.2
- package moved into BuildService
- no patch needed
* Tue Feb 14 2006 pnemec@suse.cz
- remove Mozilla and Mozilla mail from menu xml files
- added MozillaFirefox and MozillaThunderbird to xml files
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 pnemec@suse.cz
- update to 4.2.3
* Mon Nov 14 2005 pnemec@suse.cz
- create devel package
* Tue Sep 20 2005 pnemec@suse.cz
- fix gcc strict aliasing warning
* Wed Sep 14 2005 cthiel@suse.de
- specfile cleanup
* Mon Aug  1 2005 cthiel@suse.de
- fixed Requires
* Wed May 18 2005 cthiel@suse.de
- update to 4.2.2
* Tue Apr 12 2005 cthiel@suse.de
- update to 4.2.1.1
* Thu Nov  4 2004 mmj@suse.de
- locale rename: no -> nb
* Mon May 17 2004 ltinkl@suse.cz
- initial version
